Documentation
¶
Index ¶
Constants ¶
const (
// Name is a const for the name of this component.
Name = "gardener-seed-admission-controller"
)
Variables ¶
This section is empty.
Functions ¶
func NewSeedAdmissionControllerCommand ¶ added in v1.17.0
NewSeedAdmissionControllerCommand creates a new *cobra.Command able to run gardener-seed-admission-controller.
Types ¶
type Options ¶
type Options struct {
// BindAddress is the address the HTTP server should bind to.
BindAddress string
// Port is the port that should be opened by the HTTP server.
Port int
// ServerCertDir is the path to server TLS cert and key.
ServerCertDir string
// MetricsBindAddress is the TCP address that the controller should bind to
// for serving prometheus metrics.
// It can be set to "0" to disable the metrics serving.
MetricsBindAddress string
// HealthBindAddress is the TCP address that the controller should bind to for serving health probes.
HealthBindAddress string
// EnableProfiling enables profiling via web interface host:port/debug/pprof/.
EnableProfiling bool
// EnableContentionProfiling enables lock contention profiling, if
// enableProfiling is true.
EnableContentionProfiling bool
}
Options has all the context and parameters needed to run gardener-seed-admission-controller.
Click to show internal directories.
Click to hide internal directories.