Documentation
¶
Overview ¶
+k8s:deepcopy-gen=package
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HealthCheckConfig ¶
type HealthCheckConfig struct {
// SyncPeriod is the duration how often the existing resources are reconciled (how
// often the health check of Shoot clusters is performed (only if no operation is
// already running on them).
// defaults to 30 sec
SyncPeriod metav1.Duration `json:"syncPeriod"`
// ShootRESTOptions allow overwriting certain default settings of the shoot rest.Config.
// +optional
ShootRESTOptions *RESTOptions `json:"shootRESTOptions,omitempty"`
}
HealthCheckConfig contains the health check controller configuration.
func (*HealthCheckConfig) DeepCopy ¶
func (in *HealthCheckConfig) DeepCopy() *HealthCheckConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HealthCheckConfig.
func (*HealthCheckConfig) DeepCopyInto ¶
func (in *HealthCheckConfig) DeepCopyInto(out *HealthCheckConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RESTOptions ¶
type RESTOptions struct {
// QPS indicates the maximum QPS to the master from this client.
// +optional
QPS *float32 `json:"qps,omitempty"`
// Maximum burst for throttle.
// +optional
Burst *int `json:"burst,omitempty"`
// The maximum length of time to wait before giving up on a server request. A value of zero means no timeout.
// +optional
Timeout *time.Duration `json:"timeout,omitempty"`
}
RESTOptions define a subset of optional parameters for a rest.Config. Default values when unset are those from https://github.com/kubernetes/client-go/blob/master/rest/config.go.
func (*RESTOptions) DeepCopy ¶
func (in *RESTOptions) DeepCopy() *RESTOptions
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RESTOptions.
func (*RESTOptions) DeepCopyInto ¶
func (in *RESTOptions) DeepCopyInto(out *RESTOptions)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.