Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HealthCheckConfig ¶
type HealthCheckConfig struct {
// SyncPeriod is the duration how often the existing resources are reconciled (how
// often the health check of Shoot clusters is performed (only if no operation is
// already running on them).
// defaults to 30 sec
SyncPeriod metav1.Duration
}
HealthCheckConfig contains the health check controller configuration.
Click to show internal directories.
Click to hide internal directories.