Documentation
¶
Index ¶
- func NewClusterOpenIDConnectPresetInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterOpenIDConnectPresetInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredOpenIDConnectPresetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewOpenIDConnectPresetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ClusterOpenIDConnectPresetInformer
- type Interface
- type OpenIDConnectPresetInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterOpenIDConnectPresetInformer ¶
func NewClusterOpenIDConnectPresetInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterOpenIDConnectPresetInformer constructs a new informer for ClusterOpenIDConnectPreset type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterOpenIDConnectPresetInformer ¶
func NewFilteredClusterOpenIDConnectPresetInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterOpenIDConnectPresetInformer constructs a new informer for ClusterOpenIDConnectPreset type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredOpenIDConnectPresetInformer ¶
func NewFilteredOpenIDConnectPresetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredOpenIDConnectPresetInformer constructs a new informer for OpenIDConnectPreset type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewOpenIDConnectPresetInformer ¶
func NewOpenIDConnectPresetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewOpenIDConnectPresetInformer constructs a new informer for OpenIDConnectPreset type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ClusterOpenIDConnectPresetInformer ¶
type ClusterOpenIDConnectPresetInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterOpenIDConnectPresetLister
}
ClusterOpenIDConnectPresetInformer provides access to a shared informer and lister for ClusterOpenIDConnectPresets.
type Interface ¶
type Interface interface {
// ClusterOpenIDConnectPresets returns a ClusterOpenIDConnectPresetInformer.
ClusterOpenIDConnectPresets() ClusterOpenIDConnectPresetInformer
// OpenIDConnectPresets returns a OpenIDConnectPresetInformer.
OpenIDConnectPresets() OpenIDConnectPresetInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type OpenIDConnectPresetInformer ¶
type OpenIDConnectPresetInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.OpenIDConnectPresetLister
}
OpenIDConnectPresetInformer provides access to a shared informer and lister for OpenIDConnectPresets.