Documentation
¶
Index ¶
Constants ¶
const ManagedResourceName = "shoot-core-gardeneraccess"
ManagedResourceName is the name of the ManagedResource containing the resource specifications.
Variables ¶
var TimeoutWaitForManagedResource = 2 * time.Minute
TimeoutWaitForManagedResource is the timeout used while waiting for the ManagedResources to become healthy or deleted.
Functions ¶
func New ¶
func New( client client.Client, namespace string, secretsManager secretsmanager.Interface, values Values, ) component.DeployWaiter
New creates a new instance of the deployer for GardenerAccess.
Types ¶
type Values ¶
type Values struct {
// ServerOutOfCluster is the out-of-cluster address of a kube-apiserver.
ServerOutOfCluster string
// ServerInCluster is the in-cluster address of a kube-apiserver.
ServerInCluster string
// ManagedResourceLabels are labels added to the ManagedResource.
ManagedResourceLabels map[string]string
}
Values contains configurations for the component.
Click to show internal directories.
Click to hide internal directories.