Documentation
¶
Index ¶
Constants ¶
const ( // DeploymentName is the name of the deployment. DeploymentName = "gardener-admission-controller" // ServiceName is the name of the service. ServiceName = DeploymentName // ManagedResourceNameRuntime is the name of the ManagedResource for the runtime resources. ManagedResourceNameRuntime = "gardener-admission-controller-runtime" // ManagedResourceNameVirtual is the name of the ManagedResource for the virtual resources. ManagedResourceNameVirtual = "gardener-admission-controller-virtual" )
Variables ¶
var TimeoutWaitForManagedResource = 5 * time.Minute
TimeoutWaitForManagedResource is the timeout used while waiting for the ManagedResources to become healthy or deleted.
Functions ¶
func New ¶
func New(client client.Client, namespace string, secretsManager secretsmanager.Interface, values Values) component.DeployWaiter
New creates a new instance of DeployWaiter for the gardener-admission-controller.
Types ¶
type Values ¶
type Values struct {
// LogLevel is the configured log level for the gardener-admission-controller.
LogLevel string
// Image is the container image used for the gardener-admission-controller pods.
Image string
// ResourceAdmissionConfiguration is the configuration for gardener-admission-controller's resource-size validator.
ResourceAdmissionConfiguration *admissioncontrollerv1alpha1.ResourceAdmissionConfiguration
// RuntimeVersion is the Kubernetes version of the runtime cluster.
RuntimeVersion *semver.Version
// SeedRestrictionEnabled specifies whether the seed-restriction webhook is enabled.
SeedRestrictionEnabled bool
// TopologyAwareRoutingEnabled determines whether topology aware hints are intended for the gardener-admission-controller.
TopologyAwareRoutingEnabled bool
}
Values contains configuration values for the gardener-admission-controller resources.
Click to show internal directories.
Click to hide internal directories.