Documentation
¶
Index ¶
Constants ¶
const (
// ManagedResourceName is the name of the managed resource for the resources.
ManagedResourceName = "hvpa"
)
Variables ¶
var TimeoutWaitForManagedResource = 2 * time.Minute
TimeoutWaitForManagedResource is the timeout used while waiting for the ManagedResources to become healthy or deleted.
Functions ¶
func CentralLoggingConfiguration ¶
func CentralLoggingConfiguration() (component.CentralLoggingConfig, error)
CentralLoggingConfiguration returns a fluent-bit parser and filter for the HVPA logs.
func CentralMonitoringConfiguration ¶
func CentralMonitoringConfiguration() (component.CentralMonitoringConfig, error)
CentralMonitoringConfiguration returns scrape configs for the central Prometheus.
Types ¶
type Interface ¶
type Interface interface {
component.DeployWaiter
}
Interface contains functions for an HVPA deployer.
type Values ¶
type Values struct {
// Image is the container image.
Image string
// KubernetesVersion is the version of the runtime cluster.
KubernetesVersion *semver.Version
// PriorityClassName is the name of the priority class.
PriorityClassName string
}
Values is a set of configuration values for the HVPA component.
Click to show internal directories.
Click to hide internal directories.