Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var TimeoutWaitForManagedResource = 2 * time.Minute
TimeoutWaitForManagedResource is the timeout used while waiting for the ManagedResources to become healthy or deleted.
Functions ¶
func CentralLoggingConfiguration ¶
func CentralLoggingConfiguration() (component.CentralLoggingConfig, error)
CentralLoggingConfiguration returns a fluent-bit parser and filter for the VPNShoot logs.
func New ¶
func New( client client.Client, namespace string, secretsManager secretsmanager.Interface, values Values, ) component.DeployWaiter
New creates a new instance of DeployWaiter for vpnshoot
Types ¶
type ReversedVPNValues ¶
type ReversedVPNValues struct {
// Header is the header for the ReversedVPN.
Header string
// Endpoint is the endpoint for the ReversedVPN.
Endpoint string
// OpenVPNPort is the port for the ReversedVPN.
OpenVPNPort int32
// IPFamilies are the IPFamilies of the shoot.
IPFamilies []gardencorev1beta1.IPFamily
}
ReversedVPNValues contains the configuration values for the ReversedVPN.
type Values ¶
type Values struct {
// Image is the container image used for vpnShoot.
Image string
// KubernetesVersion is the Kubernetes version of the Shoot.
KubernetesVersion *semver.Version
// PodAnnotations is the set of additional annotations to be used for the pods.
PodAnnotations map[string]string
// VPAEnabled marks whether VerticalPodAutoscaler is enabled for the shoot.
VPAEnabled bool
// ReversedVPN contains the configuration values for the ReversedVPN.
ReversedVPN ReversedVPNValues
// HighAvailabilityEnabled marks whether HA is enabled for VPN.
HighAvailabilityEnabled bool
// HighAvailabilityNumberOfSeedServers is the number of VPN seed servers used for HA
HighAvailabilityNumberOfSeedServers int
// HighAvailabilityNumberOfShootClients is the number of VPN shoot clients used for HA
HighAvailabilityNumberOfShootClients int
}
Values is a set of configuration values for the VPNShoot component.
Click to show internal directories.
Click to hide internal directories.