gardenletlifecycle

package
v1.140.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: Apache-2.0 Imports: 28 Imported by: 0

Documentation

Index

Constants

const ControllerName = "gardenlet-lifecycle"

ControllerName is the name of this controller.

Variables

This section is empty.

Functions

This section is empty.

Types

type Reconciler

type Reconciler struct {
	Client         client.Client
	Config         controllermanagerconfigv1alpha1.SeedControllerConfiguration
	Clock          clock.Clock
	LeaseNamespace string
}

Reconciler reconciles Seeds or self-hosted Shoots and checks whether the responsible gardenlet is regularly sending heartbeats. If not, it sets the GardenletReady condition to Unknown after some grace period passed. If the gardenlet still did not send heartbeats and another grace period passed then also all (other) Shoot conditions and constraints are set to Unknown.

func (*Reconciler) AddToManager

func (r *Reconciler) AddToManager(mgr manager.Manager) error

AddToManager adds Reconciler to the given manager.

func (*Reconciler) EventHandler

EventHandler returns a handler for events.

func (*Reconciler) Reconcile

func (r *Reconciler) Reconcile(ctx context.Context, req Request) (reconcile.Result, error)

Reconcile reconciles Seeds or self-hosted Shoots and checks whether the responsible gardenlet is regularly sending heartbeats. If not, it sets the GardenletReady condition to Unknown after some grace period passed. If the gardenlet still did not send heartbeats and another grace period passed then also all (other) Shoot conditions and constraints are set to Unknown.

type Request

type Request struct {
	reconcile.Request

	IsSelfHostedShoot bool
}

Request contains the namespace/name of the object as well as information whether it is a self-hosted Shoot.

Jump to