Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type ConditionThreshold
- type ControllerConfiguration
- type GardenCareControllerConfiguration
- type GardenControllerConfig
- type NetworkPolicyControllerConfiguration
- type NodeTolerationConfiguration
- type OperatorConfiguration
- type Server
- type ServerConfiguration
- type VPAEvictionRequirementsControllerConfiguration
Constants ¶
const GroupName = "operator.config.gardener.cloud"
GroupName is the group name used in this package.
Variables ¶
var ( // SchemeBuilder used to register the Shoot resource. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is a pointer to SchemeBuilder.AddToScheme. AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type ConditionThreshold ¶ added in v1.76.0
type ConditionThreshold struct {
// Type is the type of the condition to define the threshold for.
Type string
// Duration is the duration how long the condition can stay in the progressing state.
Duration metav1.Duration
}
ConditionThreshold defines the threshold of the given condition type.
func (*ConditionThreshold) DeepCopy ¶ added in v1.76.0
func (in *ConditionThreshold) DeepCopy() *ConditionThreshold
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConditionThreshold.
func (*ConditionThreshold) DeepCopyInto ¶ added in v1.76.0
func (in *ConditionThreshold) DeepCopyInto(out *ConditionThreshold)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ControllerConfiguration ¶
type ControllerConfiguration struct {
// Garden is the configuration for the garden controller.
Garden GardenControllerConfig
// GardenCare is the configuration for the garden care controller
GardenCare GardenCareControllerConfiguration
// NetworkPolicy is the configuration for the NetworkPolicy controller.
NetworkPolicy NetworkPolicyControllerConfiguration
// VPAEvictionRequirements is the configuration for the VPAEvictionrequirements controller.
VPAEvictionRequirements VPAEvictionRequirementsControllerConfiguration
}
ControllerConfiguration defines the configuration of the controllers.
func (*ControllerConfiguration) DeepCopy ¶
func (in *ControllerConfiguration) DeepCopy() *ControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControllerConfiguration.
func (*ControllerConfiguration) DeepCopyInto ¶
func (in *ControllerConfiguration) DeepCopyInto(out *ControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GardenCareControllerConfiguration ¶ added in v1.76.0
type GardenCareControllerConfiguration struct {
// SyncPeriod is the duration how often the existing resources are reconciled (how
// often the health check is performed).
SyncPeriod *metav1.Duration
// ConditionThresholds defines the condition threshold per condition type.
ConditionThresholds []ConditionThreshold
}
GardenCareControllerConfiguration defines the configuration of the GardenCare controller.
func (*GardenCareControllerConfiguration) DeepCopy ¶ added in v1.76.0
func (in *GardenCareControllerConfiguration) DeepCopy() *GardenCareControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GardenCareControllerConfiguration.
func (*GardenCareControllerConfiguration) DeepCopyInto ¶ added in v1.76.0
func (in *GardenCareControllerConfiguration) DeepCopyInto(out *GardenCareControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GardenControllerConfig ¶
type GardenControllerConfig struct {
// ConcurrentSyncs is the number of concurrent worker routines for this controller.
ConcurrentSyncs *int
// SyncPeriod is the duration how often the controller performs its reconciliation.
SyncPeriod *metav1.Duration
// ETCDConfig contains an optional configuration for the
// backup compaction feature of ETCD backup-restore functionality.
ETCDConfig *gardenletconfig.ETCDConfig
}
GardenControllerConfig is the configuration for the garden controller.
func (*GardenControllerConfig) DeepCopy ¶
func (in *GardenControllerConfig) DeepCopy() *GardenControllerConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GardenControllerConfig.
func (*GardenControllerConfig) DeepCopyInto ¶
func (in *GardenControllerConfig) DeepCopyInto(out *GardenControllerConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NetworkPolicyControllerConfiguration ¶ added in v1.71.0
type NetworkPolicyControllerConfiguration struct {
// ConcurrentSyncs is the number of concurrent worker routines for this controller.
ConcurrentSyncs *int
// AdditionalNamespaceSelectors is a list of label selectors for additional namespaces that should be considered by
// the controller.
AdditionalNamespaceSelectors []metav1.LabelSelector
}
NetworkPolicyControllerConfiguration defines the configuration of the NetworkPolicy controller.
func (*NetworkPolicyControllerConfiguration) DeepCopy ¶ added in v1.71.0
func (in *NetworkPolicyControllerConfiguration) DeepCopy() *NetworkPolicyControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyControllerConfiguration.
func (*NetworkPolicyControllerConfiguration) DeepCopyInto ¶ added in v1.71.0
func (in *NetworkPolicyControllerConfiguration) DeepCopyInto(out *NetworkPolicyControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NodeTolerationConfiguration ¶ added in v1.71.0
type NodeTolerationConfiguration struct {
// DefaultNotReadyTolerationSeconds specifies the seconds for the `node.kubernetes.io/not-ready` toleration that
// should be added to pods not already tolerating this taint.
DefaultNotReadyTolerationSeconds *int64
// DefaultUnreachableTolerationSeconds specifies the seconds for the `node.kubernetes.io/unreachable` toleration that
// should be added to pods not already tolerating this taint.
DefaultUnreachableTolerationSeconds *int64
}
NodeTolerationConfiguration contains information about node toleration options.
func (*NodeTolerationConfiguration) DeepCopy ¶ added in v1.71.0
func (in *NodeTolerationConfiguration) DeepCopy() *NodeTolerationConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeTolerationConfiguration.
func (*NodeTolerationConfiguration) DeepCopyInto ¶ added in v1.71.0
func (in *NodeTolerationConfiguration) DeepCopyInto(out *NodeTolerationConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OperatorConfiguration ¶
type OperatorConfiguration struct {
metav1.TypeMeta
// RuntimeClientConnection specifies the kubeconfig file and the client connection settings for the proxy server to
// use when communicating with the kube-apiserver of the runtime cluster.
RuntimeClientConnection componentbaseconfig.ClientConnectionConfiguration
// VirtualClientConnection specifies the kubeconfig file and the client connection settings for the proxy server to
// use when communicating with the kube-apiserver of the virtual cluster.
VirtualClientConnection componentbaseconfig.ClientConnectionConfiguration
// LeaderElection defines the configuration of leader election client.
LeaderElection componentbaseconfig.LeaderElectionConfiguration
// LogLevel is the level/severity for the logs. Must be one of [info,debug,error].
LogLevel string
// LogFormat is the output format for the logs. Must be one of [text,json].
LogFormat string
// Server defines the configuration of the HTTP server.
Server ServerConfiguration
// Debugging holds configuration for Debugging related features.
Debugging *componentbaseconfig.DebuggingConfiguration
// FeatureGates is a map of feature names to bools that enable or disable alpha/experimental features. This field
// modifies piecemeal the built-in default values from "github.com/gardener/gardener/pkg/operator/features/features.go".
// Default: nil
FeatureGates map[string]bool
// Controllers defines the configuration of the controllers.
Controllers ControllerConfiguration
// NodeToleration contains optional settings for default tolerations.
NodeToleration *NodeTolerationConfiguration
}
OperatorConfiguration defines the configuration for the Gardener operator.
func (*OperatorConfiguration) DeepCopy ¶
func (in *OperatorConfiguration) DeepCopy() *OperatorConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OperatorConfiguration.
func (*OperatorConfiguration) DeepCopyInto ¶
func (in *OperatorConfiguration) DeepCopyInto(out *OperatorConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*OperatorConfiguration) DeepCopyObject ¶
func (in *OperatorConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type Server ¶
type Server struct {
// BindAddress is the IP address on which to listen for the specified port.
BindAddress string
// Port is the port on which to serve requests.
Port int
}
Server contains information for HTTP(S) server configuration.
func (*Server) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Server.
func (*Server) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServerConfiguration ¶
type ServerConfiguration struct {
// Webhooks is the configuration for the HTTPS webhook server.
Webhooks Server
// HealthProbes is the configuration for serving the healthz and readyz endpoints.
HealthProbes *Server
// Metrics is the configuration for serving the metrics endpoint.
Metrics *Server
}
ServerConfiguration contains details for the HTTP(S) servers.
func (*ServerConfiguration) DeepCopy ¶
func (in *ServerConfiguration) DeepCopy() *ServerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerConfiguration.
func (*ServerConfiguration) DeepCopyInto ¶
func (in *ServerConfiguration) DeepCopyInto(out *ServerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VPAEvictionRequirementsControllerConfiguration ¶ added in v1.94.0
type VPAEvictionRequirementsControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on events.
ConcurrentSyncs *int
}
VPAEvictionRequirementsControllerConfiguration defines the configuration of the VPAEvictionRequirements controller.
func (*VPAEvictionRequirementsControllerConfiguration) DeepCopy ¶ added in v1.94.0
func (in *VPAEvictionRequirementsControllerConfiguration) DeepCopy() *VPAEvictionRequirementsControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VPAEvictionRequirementsControllerConfiguration.
func (*VPAEvictionRequirementsControllerConfiguration) DeepCopyInto ¶ added in v1.94.0
func (in *VPAEvictionRequirementsControllerConfiguration) DeepCopyInto(out *VPAEvictionRequirementsControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.