Documentation
¶
Index ¶
Constants ¶
const ControllerName = "backupbucket_controller"
ControllerName is the name of the controller.
Variables ¶
var ( // DefaultAddOptions are the default AddOptions for AddToManager. DefaultAddOptions = backupoptions.AddOptions{} )
Functions ¶
func AddToManager ¶
AddToManager adds a controller with the default Options.
func AddToManagerWithOptions ¶
func AddToManagerWithOptions(mgr manager.Manager, opts backupoptions.AddOptions) error
AddToManagerWithOptions adds a controller with the given Options to the given manager. The opts.Reconciler is being set with a newly instantiated actuator.
Types ¶
type AddOptions ¶
type AddOptions struct {
// BackupBucketLocalDir is the directory of the backupbucket.
BackupBucketLocalDir string
// Controller are the controller.Options.
Controller controller.Options
// IgnoreOperationAnnotation specifies whether to ignore the operation annotation or not.
IgnoreOperationAnnotation bool
}
AddOptions are options to apply when adding the backupbucket controller to the manager.
Click to show internal directories.
Click to hide internal directories.