Documentation
¶
Index ¶
- Constants
- Variables
- func AddToManager(ctx context.Context, mgr manager.Manager) error
- func AddToManagerWithOptions(ctx context.Context, mgr manager.Manager, opts AddOptions) error
- func HasNodesInMultipleZones(ctx context.Context, c client.Reader) (bool, error)
- type AddOptions
- type ControllerConfig
- type ControllerOptions
Constants ¶
const ControllerName = "service"
ControllerName is the name of the controller.
Variables ¶
var DefaultAddOptions = AddOptions{}
DefaultAddOptions are the default AddOptions for AddToManager.
Functions ¶
func AddToManager ¶
AddToManager adds a controller with the default Options.
func AddToManagerWithOptions ¶
AddToManagerWithOptions adds a controller with the given Options to the given manager. The opts.Reconciler is being set with a newly instantiated actuator.
Types ¶
type AddOptions ¶
type AddOptions struct {
// Controller are the controller.Options.
Controller controller.Options
// HostIP is the IP address of the host.
HostIP string
// Zone0IP is the IP address to be used for the zone 0 istio ingress gateway.
Zone0IP string
// Zone1IP is the IP address to be used for the zone 1 istio ingress gateway.
Zone1IP string
// Zone2IP is the IP address to be used for the zone 2 istio ingress gateway.
Zone2IP string
}
AddOptions are options to apply when adding the local infrastructure controller to the manager.
type ControllerConfig ¶
type ControllerConfig struct {
// MaxConcurrentReconciles is the maximum number of concurrent reconciles.
MaxConcurrentReconciles int
// HostIP is the host ip.
HostIP string
// Zone0IP is the IP address to be used for the zone 0 istio ingress gateway.
Zone0IP string
// Zone1IP is the IP address to be used for the zone 1 istio ingress gateway.
Zone1IP string
// Zone2IP is the IP address to be used for the zone 2 istio ingress gateway.
Zone2IP string
}
ControllerConfig is a completed controller configuration.
func (*ControllerConfig) Apply ¶
func (c *ControllerConfig) Apply(opts *AddOptions)
Apply sets the values of this ControllerConfig in the given AddOptions.
type ControllerOptions ¶
type ControllerOptions struct {
// MaxConcurrentReconciles are the maximum concurrent reconciles.
MaxConcurrentReconciles int
// HostIP is the host ip.
HostIP string
// Zone0IP is the IP address to be used for the zone 0 istio ingress gateway.
Zone0IP string
// Zone1IP is the IP address to be used for the zone 1 istio ingress gateway.
Zone1IP string
// Zone2IP is the IP address to be used for the zone 2 istio ingress gateway.
Zone2IP string
// contains filtered or unexported fields
}
ControllerOptions are command line options that can be set for controller.Options.
func (*ControllerOptions) AddFlags ¶
func (c *ControllerOptions) AddFlags(fs *pflag.FlagSet)
AddFlags implements Flagger.AddFlags.
func (*ControllerOptions) Complete ¶
func (c *ControllerOptions) Complete() error
Complete implements Completer.Complete.
func (*ControllerOptions) Completed ¶
func (c *ControllerOptions) Completed() *ControllerConfig
Completed returns the completed ControllerConfig. Only call this if `Complete` was successful.