Documentation
¶
Index ¶
Constants ¶
const ControllerName = "health"
ControllerName is the name of the controller.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reconciler ¶
type Reconciler struct {
SourceClient client.Client
TargetClient client.Client
TargetScheme *runtime.Scheme
Config config.HealthControllerConfig
Clock clock.Clock
ClassFilter *resourcemanagerpredicate.ClassFilter
// contains filtered or unexported fields
}
Reconciler performs health checks for resources managed as part of ManagedResources.
func (*Reconciler) AddToManager ¶
func (r *Reconciler) AddToManager(ctx context.Context, mgr manager.Manager, sourceCluster, targetCluster cluster.Cluster, clusterID string) error
AddToManager adds Reconciler to the given manager.
func (*Reconciler) EnqueueCreateAndUpdate ¶
func (r *Reconciler) EnqueueCreateAndUpdate() handler.EventHandler
EnqueueCreateAndUpdate returns an event handler which only enqueues create and update events.
Click to show internal directories.
Click to hide internal directories.