Documentation
¶
Index ¶
Constants ¶
const (
// Name is a const for the name of this component.
Name = "gardener-seed-admission-controller"
)
Variables ¶
This section is empty.
Functions ¶
func NewSeedAdmissionControllerCommand ¶ added in v1.17.0
NewSeedAdmissionControllerCommand creates a new *cobra.Command able to run gardener-seed-admission-controller.
Types ¶
type Options ¶
type Options struct {
// BindAddress is the address the HTTP server should bind to.
BindAddress string
// Port is the port that should be opened by the HTTP server.
Port int
// ServerCertDir is the path to server TLS cert and key.
ServerCertDir string
// AllowInvalidExtensionResources causes the seed-admission-controller to allow invalid extension resources.
AllowInvalidExtensionResources bool
}
Options has all the context and parameters needed to run gardener-seed-admission-controller.
Click to show internal directories.
Click to hide internal directories.