Documentation
¶
Index ¶
- func GetAPIServerSNIDomains(domains []string, sni operatorv1alpha1.SNI) []string
- func GetCARotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
- func GetDNSProviders(garden *operatorv1alpha1.Garden) []operatorv1alpha1.DNSProvider
- func GetETCDEncryptionKeyRotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
- func GetETCDMainBackup(garden *operatorv1alpha1.Garden) *operatorv1alpha1.Backup
- func GetEncryptedResourcesInStatus(gardenStatus operatorv1alpha1.GardenStatus) []string
- func GetEncryptionProviderTypeInStatus(gardenStatus operatorv1alpha1.GardenStatus) gardencorev1beta1.EncryptionProviderType
- func GetGardenAPIServerEncryptionProviderType(apiServerConfig *operatorv1alpha1.GardenerAPIServerConfig) gardencorev1beta1.EncryptionProviderType
- func GetGardenerOperations(annotations map[string]string) []string
- func GetKubeAPIServerEncryptionProviderType(apiServerConfig *operatorv1alpha1.KubeAPIServerConfig) gardencorev1beta1.EncryptionProviderType
- func GetServiceAccountKeyRotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
- func GetWorkloadIdentityKeyRotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
- func HighAvailabilityEnabled(garden *operatorv1alpha1.Garden) bool
- func IsObservabilityRotationInitiationTimeAfterLastCompletionTime(credentials *operatorv1alpha1.Credentials) bool
- func MutateCARotation(garden *operatorv1alpha1.Garden, ...)
- func MutateETCDEncryptionKeyRotation(garden *operatorv1alpha1.Garden, ...)
- func MutateObservabilityRotation(garden *operatorv1alpha1.Garden, ...)
- func MutateServiceAccountKeyRotation(garden *operatorv1alpha1.Garden, ...)
- func MutateWorkloadIdentityKeyRotation(garden *operatorv1alpha1.Garden, ...)
- func ShouldETCDEncryptionKeyRotationBeAutoCompleteAfterPrepared(credentials *operatorv1alpha1.Credentials) booldeprecated
- func TopologyAwareRoutingEnabled(settings *operatorv1alpha1.Settings) bool
- func VerticalPodAutoscalerMaxAllowed(settings *operatorv1alpha1.Settings) corev1.ResourceList
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAPIServerSNIDomains ¶ added in v1.123.0
func GetAPIServerSNIDomains(domains []string, sni operatorv1alpha1.SNI) []string
GetAPIServerSNIDomains returns the domains which match a SNI domain pattern.
func GetCARotationPhase ¶
func GetCARotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
GetCARotationPhase returns the specified garden CA rotation phase or an empty string
func GetDNSProviders ¶ added in v1.114.0
func GetDNSProviders(garden *operatorv1alpha1.Garden) []operatorv1alpha1.DNSProvider
GetDNSProviders returns the DNS providers for the given garden object or nil if non are configured.
func GetETCDEncryptionKeyRotationPhase ¶ added in v1.66.0
func GetETCDEncryptionKeyRotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
GetETCDEncryptionKeyRotationPhase returns the specified garden ETCD encryption key rotation phase or an empty string.
func GetETCDMainBackup ¶ added in v1.114.0
func GetETCDMainBackup(garden *operatorv1alpha1.Garden) *operatorv1alpha1.Backup
GetETCDMainBackup returns the backup configuration for etcd main of the given garden object or nil if not configured.
func GetEncryptedResourcesInStatus ¶
func GetEncryptedResourcesInStatus(gardenStatus operatorv1alpha1.GardenStatus) []string
GetEncryptedResourcesInStatus returns the encrypted resources from the garden status.
func GetEncryptionProviderTypeInStatus ¶
func GetEncryptionProviderTypeInStatus(gardenStatus operatorv1alpha1.GardenStatus) gardencorev1beta1.EncryptionProviderType
GetEncryptionProviderTypeInStatus returns the encryption provider from the garden status.
func GetGardenAPIServerEncryptionProviderType ¶
func GetGardenAPIServerEncryptionProviderType(apiServerConfig *operatorv1alpha1.GardenerAPIServerConfig) gardencorev1beta1.EncryptionProviderType
GetGardenAPIServerEncryptionProviderType returns the Garden's encryption provider type from the garden-apiserver config.
func GetGardenerOperations ¶
GetGardenerOperations returns the Garden's gardener operations specified in the operation annotation.
func GetKubeAPIServerEncryptionProviderType ¶
func GetKubeAPIServerEncryptionProviderType(apiServerConfig *operatorv1alpha1.KubeAPIServerConfig) gardencorev1beta1.EncryptionProviderType
GetKubeAPIServerEncryptionProviderType returns the Garden's encryption provider type from the kube-apiserver config.
func GetServiceAccountKeyRotationPhase ¶ added in v1.66.0
func GetServiceAccountKeyRotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
GetServiceAccountKeyRotationPhase returns the specified garden service account key rotation phase or an empty string.
func GetWorkloadIdentityKeyRotationPhase ¶ added in v1.103.0
func GetWorkloadIdentityKeyRotationPhase(credentials *operatorv1alpha1.Credentials) gardencorev1beta1.CredentialsRotationPhase
GetWorkloadIdentityKeyRotationPhase returns the specified garden workload identity key rotation phase or an empty string.
func HighAvailabilityEnabled ¶ added in v1.68.0
func HighAvailabilityEnabled(garden *operatorv1alpha1.Garden) bool
HighAvailabilityEnabled returns true if the high-availability is enabled.
func IsObservabilityRotationInitiationTimeAfterLastCompletionTime ¶ added in v1.79.0
func IsObservabilityRotationInitiationTimeAfterLastCompletionTime(credentials *operatorv1alpha1.Credentials) bool
IsObservabilityRotationInitiationTimeAfterLastCompletionTime returns true when the lastInitiationTime in the .status.credentials.rotation.observability field is newer than the lastCompletionTime. This is also true if the lastCompletionTime is unset.
func MutateCARotation ¶
func MutateCARotation(garden *operatorv1alpha1.Garden, f func(rotation *gardencorev1beta1.CARotation))
MutateCARotation mutates the .status.credentials.rotation.certificateAuthorities field based on the provided mutation function. If the field is nil then it is initialized.
func MutateETCDEncryptionKeyRotation ¶ added in v1.66.0
func MutateETCDEncryptionKeyRotation(garden *operatorv1alpha1.Garden, f func(*gardencorev1beta1.ETCDEncryptionKeyRotation))
MutateETCDEncryptionKeyRotation mutates the .status.credentials.rotation.etcdEncryptionKey field based on the provided mutation function. If the field is nil then it is initialized.
func MutateObservabilityRotation ¶ added in v1.79.0
func MutateObservabilityRotation(garden *operatorv1alpha1.Garden, f func(*gardencorev1beta1.ObservabilityRotation))
MutateObservabilityRotation mutates the .status.credentials.rotation.observability field based on the provided mutation function. If the field is nil then it is initialized.
func MutateServiceAccountKeyRotation ¶ added in v1.66.0
func MutateServiceAccountKeyRotation(garden *operatorv1alpha1.Garden, f func(*gardencorev1beta1.ServiceAccountKeyRotation))
MutateServiceAccountKeyRotation mutates the .status.credentials.rotation.serviceAccountKey field based on the provided mutation function. If the field is nil then it is initialized.
func MutateWorkloadIdentityKeyRotation ¶ added in v1.103.0
func MutateWorkloadIdentityKeyRotation(garden *operatorv1alpha1.Garden, f func(*operatorv1alpha1.WorkloadIdentityKeyRotation))
MutateWorkloadIdentityKeyRotation mutates the .status.credentials.rotation.workloadIdentityKey field based on the provided mutation function. If the field is nil then it is initialized.
func ShouldETCDEncryptionKeyRotationBeAutoCompleteAfterPrepared
deprecated
added in
v1.128.0
func ShouldETCDEncryptionKeyRotationBeAutoCompleteAfterPrepared(credentials *operatorv1alpha1.Credentials) bool
ShouldETCDEncryptionKeyRotationBeAutoCompleteAfterPrepared returns whether the current ETCD encryption key rotation should be auto completed after the preparation phase has finished.
Deprecated: This function will be removed in a future release. The function will be no longer needed with the removal `rotate-etcd-encryption-key-start` & `rotate-etcd-encryption-key-complete` annotations. TODO(AleksandarSavchev): Remove this after support for Kubernetes v1.33 is dropped.
func TopologyAwareRoutingEnabled ¶ added in v1.68.0
func TopologyAwareRoutingEnabled(settings *operatorv1alpha1.Settings) bool
TopologyAwareRoutingEnabled returns true if the topology-aware routing is enabled.
func VerticalPodAutoscalerMaxAllowed ¶ added in v1.125.1
func VerticalPodAutoscalerMaxAllowed(settings *operatorv1alpha1.Settings) corev1.ResourceList
VerticalPodAutoscalerMaxAllowed returns the configured vertical pod autoscaler's maximum allowed recommendation.
Types ¶
This section is empty.