Documentation
¶
Index ¶
- func NewControllerDeploymentInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredControllerDeploymentInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ControllerDeploymentInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewControllerDeploymentInformer ¶
func NewControllerDeploymentInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewControllerDeploymentInformer constructs a new informer for ControllerDeployment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredControllerDeploymentInformer ¶
func NewFilteredControllerDeploymentInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredControllerDeploymentInformer constructs a new informer for ControllerDeployment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ControllerDeploymentInformer ¶
type ControllerDeploymentInformer interface {
Informer() cache.SharedIndexInformer
Lister() corev1.ControllerDeploymentLister
}
ControllerDeploymentInformer provides access to a shared informer and lister for ControllerDeployments.
type Interface ¶
type Interface interface {
// ControllerDeployments returns a ControllerDeploymentInformer.
ControllerDeployments() ControllerDeploymentInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.