Documentation
¶
Index ¶
Constants ¶
const (
// ManagedResourceName is the name of the ManagedResource containing the resource specifications.
ManagedResourceName = "shoot-core-node-local-dns"
)
Variables ¶
var TimeoutWaitForManagedResource = 2 * time.Minute
TimeoutWaitForManagedResource is the timeout used while waiting for the ManagedResources to become healthy or deleted.
Functions ¶
This section is empty.
Types ¶
type Interface ¶
type Interface interface {
component.DeployWaiter
component.MonitoringComponent
}
Interface contains functions for a node-local-dns deployer.
type Values ¶
type Values struct {
// Image is the container image used for node-local-dns.
Image string
// VPAEnabled marks whether VerticalPodAutoscaler is enabled for the shoot.
VPAEnabled bool
// Config is the node local configuration for the shoot spec
Config *gardencorev1beta1.NodeLocalDNS
// ClusterDNS is the ClusterIP of kube-system/coredns Service
ClusterDNS string
// DNSServer is the ClusterIP of kube-system/coredns Service
DNSServer string
// KubernetesVersion is the Kubernetes version of the Shoot.
KubernetesVersion *semver.Version
}
Values is a set of configuration values for the node-local-dns component.
Click to show internal directories.
Click to hide internal directories.