Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type BastionControllerConfiguration
- type CloudProfileControllerConfiguration
- type ControllerDeploymentControllerConfiguration
- type ControllerManagerConfiguration
- type ControllerManagerControllerConfiguration
- type ControllerRegistrationControllerConfiguration
- type EventControllerConfiguration
- type ExposureClassControllerConfiguration
- type HTTPSServer
- type ManagedSeedSetControllerConfiguration
- type PlantControllerConfiguration
- type ProjectControllerConfiguration
- type QuotaConfiguration
- type QuotaControllerConfiguration
- type SecretBindingControllerConfiguration
- type SecretBindingProviderControllerConfiguration
- type SeedControllerConfiguration
- type Server
- type ServerConfiguration
- type ShootConditionsControllerConfiguration
- type ShootHibernationControllerConfiguration
- type ShootMaintenanceControllerConfiguration
- type ShootQuotaControllerConfiguration
- type ShootReferenceControllerConfiguration
- type ShootRetryControllerConfiguration
- type ShootStatusLabelControllerConfiguration
- type TLSServer
Constants ¶
const ( // ControllerManagerDefaultLockObjectNamespace is the default lock namespace for leader election. ControllerManagerDefaultLockObjectNamespace = "garden" // ControllerManagerDefaultLockObjectName is the default lock name for leader election. ControllerManagerDefaultLockObjectName = "gardener-controller-manager-leader-election" )
const GroupName = "controllermanager.config.gardener.cloud"
GroupName is the group name use in this package
Variables ¶
var ( // SchemeBuilder used to register the Shoot resource. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is a pointer to SchemeBuilder.AddToScheme. AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type BastionControllerConfiguration ¶ added in v1.24.0
type BastionControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// MaxLifetime is the maximum time a Bastion resource can exist before it is
// forcefully deleted (defaults to '24h').
MaxLifetime *metav1.Duration
}
BastionControllerConfiguration defines the configuration of the Bastion controller.
func (*BastionControllerConfiguration) DeepCopy ¶ added in v1.24.0
func (in *BastionControllerConfiguration) DeepCopy() *BastionControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BastionControllerConfiguration.
func (*BastionControllerConfiguration) DeepCopyInto ¶ added in v1.24.0
func (in *BastionControllerConfiguration) DeepCopyInto(out *BastionControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudProfileControllerConfiguration ¶
type CloudProfileControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
CloudProfileControllerConfiguration defines the configuration of the CloudProfile controller.
func (*CloudProfileControllerConfiguration) DeepCopy ¶
func (in *CloudProfileControllerConfiguration) DeepCopy() *CloudProfileControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudProfileControllerConfiguration.
func (*CloudProfileControllerConfiguration) DeepCopyInto ¶
func (in *CloudProfileControllerConfiguration) DeepCopyInto(out *CloudProfileControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ControllerDeploymentControllerConfiguration ¶ added in v1.23.0
type ControllerDeploymentControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
ControllerDeploymentControllerConfiguration defines the configuration of the ControllerDeployment controller.
func (*ControllerDeploymentControllerConfiguration) DeepCopy ¶ added in v1.23.0
func (in *ControllerDeploymentControllerConfiguration) DeepCopy() *ControllerDeploymentControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControllerDeploymentControllerConfiguration.
func (*ControllerDeploymentControllerConfiguration) DeepCopyInto ¶ added in v1.23.0
func (in *ControllerDeploymentControllerConfiguration) DeepCopyInto(out *ControllerDeploymentControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ControllerManagerConfiguration ¶
type ControllerManagerConfiguration struct {
metav1.TypeMeta
// GardenClientConnection specifies the kubeconfig file and the client connection settings
// for the proxy server to use when communicating with the garden apiserver.
GardenClientConnection componentbaseconfig.ClientConnectionConfiguration
// Controllers defines the configuration of the controllers.
Controllers ControllerManagerControllerConfiguration
// LeaderElection defines the configuration of leader election client.
LeaderElection *componentbaseconfig.LeaderElectionConfiguration
// LogLevel is the level/severity for the logs. Must be one of [info,debug,error].
LogLevel string
// LogFormat is the output format for the logs. Must be one of [text,json].
LogFormat string
// KubernetesLogLevel is the log level used for Kubernetes' k8s.io/klog functions.
KubernetesLogLevel klog.Level
// Server defines the configuration of the HTTP server.
Server ServerConfiguration
// Debugging holds configuration for Debugging related features.
Debugging *componentbaseconfig.DebuggingConfiguration
// FeatureGates is a map of feature names to bools that enable or disable alpha/experimental
// features. This field modifies piecemeal the built-in default values from
// "github.com/gardener/gardener/pkg/controllermanager/features/features.go".
// Default: nil
FeatureGates map[string]bool
}
ControllerManagerConfiguration defines the configuration for the Gardener controller manager.
func (*ControllerManagerConfiguration) DeepCopy ¶
func (in *ControllerManagerConfiguration) DeepCopy() *ControllerManagerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControllerManagerConfiguration.
func (*ControllerManagerConfiguration) DeepCopyInto ¶
func (in *ControllerManagerConfiguration) DeepCopyInto(out *ControllerManagerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ControllerManagerConfiguration) DeepCopyObject ¶
func (in *ControllerManagerConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ControllerManagerControllerConfiguration ¶
type ControllerManagerControllerConfiguration struct {
// Bastion defines the configuration of the Bastion controller.
Bastion *BastionControllerConfiguration
// CloudProfile defines the configuration of the CloudProfile controller.
CloudProfile *CloudProfileControllerConfiguration
// ControllerDeployment defines the configuration of the ControllerDeployment controller.
ControllerDeployment *ControllerDeploymentControllerConfiguration
// ControllerRegistration defines the configuration of the ControllerRegistration controller.
ControllerRegistration *ControllerRegistrationControllerConfiguration
// Event defines the configuration of the Event controller. If unset, the event controller will be disabled.
Event *EventControllerConfiguration
// ExposureClass defines the configuration of the ExposureClass controller.
ExposureClass *ExposureClassControllerConfiguration
// Plant defines the configuration of the Plant controller.
Plant *PlantControllerConfiguration
// Project defines the configuration of the Project controller.
Project *ProjectControllerConfiguration
// Quota defines the configuration of the Quota controller.
Quota *QuotaControllerConfiguration
// SecretBinding defines the configuration of the SecretBinding controller.
SecretBinding *SecretBindingControllerConfiguration
// SecretBindingProvider defines the configuration of the SecretBinding provider controller.
SecretBindingProvider *SecretBindingProviderControllerConfiguration
// Seed defines the configuration of the Seed controller.
Seed *SeedControllerConfiguration
// ShootMaintenance defines the configuration of the ShootMaintenance controller.
ShootMaintenance ShootMaintenanceControllerConfiguration
// ShootQuota defines the configuration of the ShootQuota controller.
ShootQuota ShootQuotaControllerConfiguration
// ShootHibernation defines the configuration of the ShootHibernation controller.
ShootHibernation ShootHibernationControllerConfiguration
// ShootReference defines the configuration of the ShootReference controller. If unspecified, it is defaulted with `concurrentSyncs=5`.
ShootReference *ShootReferenceControllerConfiguration
// ShootRetry defines the configuration of the ShootRetry controller. If unspecified, it is defaulted with `concurrentSyncs=5`.
ShootRetry *ShootRetryControllerConfiguration
// ShootConditions defines the configuration of the ShootConditions controller. If unspecified, it is defaulted with `concurrentSyncs=5`.
ShootConditions *ShootConditionsControllerConfiguration
// ShootStatusLabel defines the configuration of the ShootStatusLabel controller.
ShootStatusLabel *ShootStatusLabelControllerConfiguration
// ManagedSeedSet defines the configuration of the ManagedSeedSet controller.
ManagedSeedSet *ManagedSeedSetControllerConfiguration
}
ControllerManagerControllerConfiguration defines the configuration of the controllers.
func (*ControllerManagerControllerConfiguration) DeepCopy ¶
func (in *ControllerManagerControllerConfiguration) DeepCopy() *ControllerManagerControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControllerManagerControllerConfiguration.
func (*ControllerManagerControllerConfiguration) DeepCopyInto ¶
func (in *ControllerManagerControllerConfiguration) DeepCopyInto(out *ControllerManagerControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ControllerRegistrationControllerConfiguration ¶
type ControllerRegistrationControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
ControllerRegistrationControllerConfiguration defines the configuration of the ControllerRegistration controller.
func (*ControllerRegistrationControllerConfiguration) DeepCopy ¶
func (in *ControllerRegistrationControllerConfiguration) DeepCopy() *ControllerRegistrationControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControllerRegistrationControllerConfiguration.
func (*ControllerRegistrationControllerConfiguration) DeepCopyInto ¶
func (in *ControllerRegistrationControllerConfiguration) DeepCopyInto(out *ControllerRegistrationControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventControllerConfiguration ¶ added in v1.9.0
type EventControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// TTLNonShootEvents is the time-to-live for all non-shoot related events (defaults to `1h`).
TTLNonShootEvents *metav1.Duration
}
EventControllerConfiguration defines the configuration of the Event controller.
func (*EventControllerConfiguration) DeepCopy ¶ added in v1.9.0
func (in *EventControllerConfiguration) DeepCopy() *EventControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventControllerConfiguration.
func (*EventControllerConfiguration) DeepCopyInto ¶ added in v1.9.0
func (in *EventControllerConfiguration) DeepCopyInto(out *EventControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ExposureClassControllerConfiguration ¶ added in v1.24.0
type ExposureClassControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
ExposureClassControllerConfiguration defines the configuration of the ExposureClass controller.
func (*ExposureClassControllerConfiguration) DeepCopy ¶ added in v1.24.0
func (in *ExposureClassControllerConfiguration) DeepCopy() *ExposureClassControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExposureClassControllerConfiguration.
func (*ExposureClassControllerConfiguration) DeepCopyInto ¶ added in v1.24.0
func (in *ExposureClassControllerConfiguration) DeepCopyInto(out *ExposureClassControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPSServer ¶
type HTTPSServer struct {
// Server is the configuration for the bind address and the port.
Server
// TLSServer contains information about the TLS configuration for a HTTPS server.
TLS TLSServer
}
HTTPSServer is the configuration for the HTTPSServer server.
func (*HTTPSServer) DeepCopy ¶
func (in *HTTPSServer) DeepCopy() *HTTPSServer
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPSServer.
func (*HTTPSServer) DeepCopyInto ¶
func (in *HTTPSServer) DeepCopyInto(out *HTTPSServer)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ManagedSeedSetControllerConfiguration ¶ added in v1.21.0
type ManagedSeedSetControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// MaxShootRetries is the maximum number of times to retry failed shoots before giving up. Defaults to 3.
MaxShootRetries *int
// SyncPeriod is the duration how often the existing resources are reconciled.
SyncPeriod metav1.Duration
}
ManagedSeedSetControllerConfiguration defines the configuration of the ManagedSeedSet controller.
func (*ManagedSeedSetControllerConfiguration) DeepCopy ¶ added in v1.21.0
func (in *ManagedSeedSetControllerConfiguration) DeepCopy() *ManagedSeedSetControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ManagedSeedSetControllerConfiguration.
func (*ManagedSeedSetControllerConfiguration) DeepCopyInto ¶ added in v1.21.0
func (in *ManagedSeedSetControllerConfiguration) DeepCopyInto(out *ManagedSeedSetControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PlantControllerConfiguration ¶ added in v0.33.0
type PlantControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// SyncPeriod is the duration how often the existing resources are reconciled.
SyncPeriod metav1.Duration
}
PlantControllerConfiguration defines the configuration of the PlantControllerConfiguration controller.
func (*PlantControllerConfiguration) DeepCopy ¶ added in v0.33.0
func (in *PlantControllerConfiguration) DeepCopy() *PlantControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PlantControllerConfiguration.
func (*PlantControllerConfiguration) DeepCopyInto ¶ added in v0.33.0
func (in *PlantControllerConfiguration) DeepCopyInto(out *PlantControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectControllerConfiguration ¶
type ProjectControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// MinimumLifetimeDays is the number of days a `Project` may exist before it is being
// checked whether it is actively used or got stale.
MinimumLifetimeDays *int
// Quotas is the default configuration matching projects are set up with if a quota is not already specified.
Quotas []QuotaConfiguration
// StaleGracePeriodDays is the number of days a `Project` may be unused/stale before a
// timestamp for an auto deletion is computed.
StaleGracePeriodDays *int
// StaleExpirationTimeDays is the number of days after a `Project` that has been marked as
// 'stale'/'unused' and passed the 'stale grace period' will be considered for auto deletion.
StaleExpirationTimeDays *int
// StaleSyncPeriod is the duration how often the reconciliation loop for stale Projects is executed.
StaleSyncPeriod *metav1.Duration
}
ProjectControllerConfiguration defines the configuration of the Project controller.
func (*ProjectControllerConfiguration) DeepCopy ¶
func (in *ProjectControllerConfiguration) DeepCopy() *ProjectControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectControllerConfiguration.
func (*ProjectControllerConfiguration) DeepCopyInto ¶
func (in *ProjectControllerConfiguration) DeepCopyInto(out *ProjectControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type QuotaConfiguration ¶ added in v1.13.0
type QuotaConfiguration struct {
// Config is the quota specification used for the project set-up.
// Only v1.ResourceQuota resources are supported.
Config runtime.Object
// ProjectSelector is an optional setting to select the projects considered for quotas.
// Defaults to empty LabelSelector, which matches all projects.
ProjectSelector *metav1.LabelSelector
}
QuotaConfiguration defines quota configurations.
func (*QuotaConfiguration) DeepCopy ¶ added in v1.13.0
func (in *QuotaConfiguration) DeepCopy() *QuotaConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new QuotaConfiguration.
func (*QuotaConfiguration) DeepCopyInto ¶ added in v1.13.0
func (in *QuotaConfiguration) DeepCopyInto(out *QuotaConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type QuotaControllerConfiguration ¶
type QuotaControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
QuotaControllerConfiguration defines the configuration of the Quota controller.
func (*QuotaControllerConfiguration) DeepCopy ¶
func (in *QuotaControllerConfiguration) DeepCopy() *QuotaControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new QuotaControllerConfiguration.
func (*QuotaControllerConfiguration) DeepCopyInto ¶
func (in *QuotaControllerConfiguration) DeepCopyInto(out *QuotaControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SecretBindingControllerConfiguration ¶
type SecretBindingControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
SecretBindingControllerConfiguration defines the configuration of the SecretBinding controller.
func (*SecretBindingControllerConfiguration) DeepCopy ¶
func (in *SecretBindingControllerConfiguration) DeepCopy() *SecretBindingControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretBindingControllerConfiguration.
func (*SecretBindingControllerConfiguration) DeepCopyInto ¶
func (in *SecretBindingControllerConfiguration) DeepCopyInto(out *SecretBindingControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SecretBindingProviderControllerConfiguration ¶ added in v1.38.0
type SecretBindingProviderControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
SecretBindingProviderControllerConfiguration defines the configuration of the SecretBinding provider controller.
func (*SecretBindingProviderControllerConfiguration) DeepCopy ¶ added in v1.38.0
func (in *SecretBindingProviderControllerConfiguration) DeepCopy() *SecretBindingProviderControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretBindingProviderControllerConfiguration.
func (*SecretBindingProviderControllerConfiguration) DeepCopyInto ¶ added in v1.38.0
func (in *SecretBindingProviderControllerConfiguration) DeepCopyInto(out *SecretBindingProviderControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SeedControllerConfiguration ¶
type SeedControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// MonitorPeriod is the duration after the seed controller will mark the `GardenletReady`
// condition in `Seed` resources as `Unknown` in case the gardenlet did not send heartbeats.
MonitorPeriod *metav1.Duration
// ShootMonitorPeriod is the duration after the seed controller will mark Gardener's conditions
// in `Shoot` resources as `Unknown` in case the gardenlet of the responsible seed cluster did
// not send heartbeats.
ShootMonitorPeriod *metav1.Duration
// SyncPeriod is the duration how often the existing resources are reconciled.
SyncPeriod metav1.Duration
}
SeedControllerConfiguration defines the configuration of the Seed controller.
func (*SeedControllerConfiguration) DeepCopy ¶
func (in *SeedControllerConfiguration) DeepCopy() *SeedControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SeedControllerConfiguration.
func (*SeedControllerConfiguration) DeepCopyInto ¶
func (in *SeedControllerConfiguration) DeepCopyInto(out *SeedControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Server ¶
type Server struct {
// BindAddress is the IP address on which to listen for the specified port.
BindAddress string
// Port is the port on which to serve requests.
Port int
}
Server contains information for HTTP(S) server configuration.
func (*Server) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Server.
func (*Server) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServerConfiguration ¶
type ServerConfiguration struct {
// HTTP is the configuration for the HTTP server.
HTTP Server
// HTTPS is the configuration for the HTTPS server.
HTTPS HTTPSServer
}
ServerConfiguration contains details for the HTTP(S) servers.
func (*ServerConfiguration) DeepCopy ¶
func (in *ServerConfiguration) DeepCopy() *ServerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerConfiguration.
func (*ServerConfiguration) DeepCopyInto ¶
func (in *ServerConfiguration) DeepCopyInto(out *ServerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootConditionsControllerConfiguration ¶ added in v1.37.0
type ShootConditionsControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
ShootConditionsControllerConfiguration defines the configuration of the ShootConditions controller.
func (*ShootConditionsControllerConfiguration) DeepCopy ¶ added in v1.37.0
func (in *ShootConditionsControllerConfiguration) DeepCopy() *ShootConditionsControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootConditionsControllerConfiguration.
func (*ShootConditionsControllerConfiguration) DeepCopyInto ¶ added in v1.37.0
func (in *ShootConditionsControllerConfiguration) DeepCopyInto(out *ShootConditionsControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootHibernationControllerConfiguration ¶
type ShootHibernationControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
ShootHibernationControllerConfiguration defines the configuration of the ShootHibernation controller.
func (*ShootHibernationControllerConfiguration) DeepCopy ¶
func (in *ShootHibernationControllerConfiguration) DeepCopy() *ShootHibernationControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootHibernationControllerConfiguration.
func (*ShootHibernationControllerConfiguration) DeepCopyInto ¶
func (in *ShootHibernationControllerConfiguration) DeepCopyInto(out *ShootHibernationControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootMaintenanceControllerConfiguration ¶
type ShootMaintenanceControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// EnableShootControlPlaneRestarter configures whether adequate pods of the shoot control plane are restarted during maintenance.
EnableShootControlPlaneRestarter *bool
// EnableShootCoreAddonRestarter configures whether some core addons to be restarted during maintenance.
EnableShootCoreAddonRestarter *bool
}
ShootMaintenanceControllerConfiguration defines the configuration of the ShootMaintenance controller.
func (*ShootMaintenanceControllerConfiguration) DeepCopy ¶
func (in *ShootMaintenanceControllerConfiguration) DeepCopy() *ShootMaintenanceControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootMaintenanceControllerConfiguration.
func (*ShootMaintenanceControllerConfiguration) DeepCopyInto ¶
func (in *ShootMaintenanceControllerConfiguration) DeepCopyInto(out *ShootMaintenanceControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootQuotaControllerConfiguration ¶
type ShootQuotaControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// SyncPeriod is the duration how often the existing resources are reconciled
// (how often Shoots referenced Quota is checked).
SyncPeriod metav1.Duration
}
ShootQuotaControllerConfiguration defines the configuration of the ShootQuota controller.
func (*ShootQuotaControllerConfiguration) DeepCopy ¶
func (in *ShootQuotaControllerConfiguration) DeepCopy() *ShootQuotaControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootQuotaControllerConfiguration.
func (*ShootQuotaControllerConfiguration) DeepCopyInto ¶
func (in *ShootQuotaControllerConfiguration) DeepCopyInto(out *ShootQuotaControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootReferenceControllerConfiguration ¶ added in v1.12.0
type ShootReferenceControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// shoots.
ConcurrentSyncs int
// ProtectAuditPolicyConfigMaps controls whether the shoot reference controller shall protect ConfigMaps containing
// audit policies and referenced in Shoots.
ProtectAuditPolicyConfigMaps *bool
}
ShootReferenceControllerConfiguration defines the configuration of the ShootReference controller.
func (*ShootReferenceControllerConfiguration) DeepCopy ¶ added in v1.12.0
func (in *ShootReferenceControllerConfiguration) DeepCopy() *ShootReferenceControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootReferenceControllerConfiguration.
func (*ShootReferenceControllerConfiguration) DeepCopyInto ¶ added in v1.12.0
func (in *ShootReferenceControllerConfiguration) DeepCopyInto(out *ShootReferenceControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootRetryControllerConfiguration ¶ added in v1.22.0
type ShootRetryControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
// RetryPeriod is the retry period for retrying failed Shoots that match certain criterion.
RetryPeriod *metav1.Duration
}
ShootRetryControllerConfiguration defines the configuration of the ShootRetry controller.
func (*ShootRetryControllerConfiguration) DeepCopy ¶ added in v1.22.0
func (in *ShootRetryControllerConfiguration) DeepCopy() *ShootRetryControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootRetryControllerConfiguration.
func (*ShootRetryControllerConfiguration) DeepCopyInto ¶ added in v1.22.0
func (in *ShootRetryControllerConfiguration) DeepCopyInto(out *ShootRetryControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ShootStatusLabelControllerConfiguration ¶ added in v1.37.0
type ShootStatusLabelControllerConfiguration struct {
// ConcurrentSyncs is the number of workers used for the controller to work on
// events.
ConcurrentSyncs int
}
ShootStatusLabelControllerConfiguration defines the configuration of the ShootStatusLabel controller.
func (*ShootStatusLabelControllerConfiguration) DeepCopy ¶ added in v1.37.0
func (in *ShootStatusLabelControllerConfiguration) DeepCopy() *ShootStatusLabelControllerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ShootStatusLabelControllerConfiguration.
func (*ShootStatusLabelControllerConfiguration) DeepCopyInto ¶ added in v1.37.0
func (in *ShootStatusLabelControllerConfiguration) DeepCopyInto(out *ShootStatusLabelControllerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TLSServer ¶
type TLSServer struct {
// ServerCertPath is the path to the server certificate file.
ServerCertPath string
// ServerKeyPath is the path to the private key file.
ServerKeyPath string
}
TLSServer contains information about the TLS configuration for a HTTPS server.
func (*TLSServer) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TLSServer.
func (*TLSServer) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.