Documentation
¶
Index ¶
Constants ¶
const ControllerName = "gardenlet-lifecycle"
ControllerName is the name of this controller.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reconciler ¶
type Reconciler struct {
Client client.Client
Config controllermanagerconfigv1alpha1.SeedControllerConfiguration
Clock clock.Clock
LeaseNamespace string
}
Reconciler reconciles Seeds or self-hosted Shoots and checks whether the responsible gardenlet is regularly sending heartbeats. If not, it sets the GardenletReady condition to Unknown after some grace period passed. If the gardenlet still did not send heartbeats and another grace period passed then also all (other) Shoot conditions and constraints are set to Unknown.
func (*Reconciler) AddToManager ¶
func (r *Reconciler) AddToManager(mgr manager.Manager) error
AddToManager adds Reconciler to the given manager.
func (*Reconciler) EventHandler ¶
func (r *Reconciler) EventHandler() handler.TypedEventHandler[client.Object, Request]
EventHandler returns a handler for events.
func (*Reconciler) Reconcile ¶
Reconcile reconciles Seeds or self-hosted Shoots and checks whether the responsible gardenlet is regularly sending heartbeats. If not, it sets the GardenletReady condition to Unknown after some grace period passed. If the gardenlet still did not send heartbeats and another grace period passed then also all (other) Shoot conditions and constraints are set to Unknown.